bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 15. Aventiure
___________________________________________________ #### Auentv wie ze Wormze widersaget
| ### <An> dem vierden morgen zwen vn– drizzech man ### sach man ze hove riten do wart ez kunt getan ### Gunther dem vil richen im wære widerseit ### von lvoge erstunden frowen div aller grozisten leit ### Vrlovp si gewnnen si solden fvr gao ### vn– iahen daz si wæren die Livdegers man ### den ê da het betwngen div Sivrides hant ### vn– in ze gisel brahte in daz Guntheres lant
###### 887 | ### Die boten er do grvzte vn– hiez si sizzen gan ### ir einer sprach dar vnder herre lat uns stan ### vnz wir sagn div mære di iv enboten sint ### ia habt ir ze vinde daz wizzet manich mvter kint
###### 888 | ### Iv widersagt <Livdegast> vn– Livdeger ### den ir da wilen tatent div gremlichen ser ### die wellent zvo ziv riten mit her in dizze lant ### do begunde zvrnen Gunther als ob ez wære im vnbechant
| ### Man hiez die trvgenære zen herbergen varn ### wie chunde sich Sivrit do da vor bewarn ### er oder ander iemen daz si trugen an ### daz wart sider in selben ze grozem leide getan
###### 890 | ### Der kvnic mit sinen frivnden rvnende gie ### Hagene von Tronege in nie gerowen lie ### noch heten ez gescheiden gnvoge skuniges man ### done wolde Hagene niedes [34r]rates abe gan
###### 891 | ### Eines tages Sivrit si rvonende vant ### do begunde vragen der helt von Niderlant ### wie get so trvrekliche der kunic un– sine man ### daz sol ich immer rechen hat im iemen iht getan
| ### Do sprach der kunic Gunther mir ist von schulden leit ### Livdegast un– Livdeger di hant mir widerseit ### si wellent nv offenliche riten in min lant ### do sprach der degen chuene daz sol div Sivrides hant
###### 893 | ### wol nach iwern eren mit vlize vnderstan ### ia getvn ich den degenen als ich han ê getan ### ich gelege in wste ir burge vn– ovch ir lant ### ê daz ich erwinde des si min hvobet iwer pfant
###### 894 | ### Ir un– iwer rechen ir sult hie bestan ### vn– lat mich zvo zin riten mit den vn– ich hie han ### daz ich iv gerne diene daz laz ich ivch gesehn ### do begunde im Gunther darvmbe groz genade iehn
| ### Do schicten si die reise mit den knehten dan ### Sivride un– sinen degenen ze sehn ez was getan ### do hiez er sich bereiten die von Niderlant ### die vzerwelten degene die svhten stritlich gewant
###### 896 | ### Do sprach der herre Sifrit min vater Sigemunt ### ir svlt hie beliben ich chvom in kurcer stvnt ### git uns got gelucke her wider an den Rin ### ir sult bi dem kunige hie vil vroliche sin
###### 897 | ### Div zeichen si an bunden also si wolden dan ### do waren da genvge Guntheres man ### dine wessen niht der mære wa von ez was geschehn ### man mohte groz gesinde do bi Sivride sehn
###### 898 | ### Ir helm vn– ovch ir pruenne si bvnden vf div march ### do wolde von dem lande vil manich reche starch ### do gie von Tronege Hagene da er Chriemh' vant ### vn– bat im gebn vrlovp si wolden rvmen daz lant
| ### So wol mich sprach do Chriemh' daz ich ie gewan den man ### der minen lieben frivnden so tar vor gestan ### also min herre Sivrit tvot den friunden min ### des mvoz ich hohes mvtes sprach div kuniginne sin
###### 900 | ### Vil lieber frivnt Hagene nv gedenchet an daz ### daz ich iv gerne diene vn– nie noch wart gehaz ### des <lazet> mich geniezen an minen lieben man ### ern sol des niht engelten hab ich Prunh' iht getan
###### 901 | ### Daz hat mih sit gerowen sprach daz edel wip ### ovch hat er so zerblowen dar vmbe minen lip ### daz ich ie beswarte ir mit rede den mvot ### daz hat vil wol errochen der helt chune vn– gvot
###### 902 | ### Ir werdet wol gefrivnde her nach disen tagen ### Chriemh' liebiv frowe ia sult ir mir sagen ### wie ich iv mvge gedienen an Sifride iwerm man ### daz tvon ich frowe gerne baz ihs niemen gan
###### 903 | ### Ich wær alle sorge sprach daz edel wip ### daz im niemen næme in stvrme sinen lip ### ob er niht volgen wolde siner vbermvot ### so wær ovch immer sicher der helt chuene vn– gvot
| ### Do sprach aber Hagene frowe habt ir wan ### ob man in mvge [34v]versenden ir svlt mich wizzen lan ### mit wie getanen listen ich daz svel vnderstan ### ich wil im zehvote immer riten vn– gan
###### 905 | ### Si sprach dv bist min mag sam bin ich der din ### ich bevilhe dir mit triwen den holden wine min ### daz dv mir behvtest den minen lieben man ### si seit im kundiv mære daz bezzer wære verlan
###### 906 | ### Si sprach min man ist chvene dar zv starch genvoch ### do er den lintrachen an dem berge slvoch ### do batte sich in dem blvote der reche vil gemeit ### da von in sit in stvremen nie dehein wafen versneit
###### 907 | ### Idoch so han ich sorge swenner in stvrme stat ### vn– vil der gereschvzze von rechen handen gat ### daz ich da verliese den minen lieben man ### hey waz ich grozzer leide dicke vmbe minnen frivnt han
###### 908 | ### Ich meldez vf genade vil lieber frivnt dir ### daz dv dine triwe behaldest ane mir ### da man da mach verhowen den minen lieben man ### daz laz ich dich wol hoere dest vf genade getan
| ### Do von <des> trachen wnden vloz daz heize blvot ### vn– sich dar inne badete der chuene reche gvot ### do gehafte im zwischen herten ein lindenblat vil breit ### da mac man in verhowen des ist mir sorgen vil bereit
###### 910 | ### Do sprach der ungetriwe vf daz sin gewant ### nêt ir ein kleinez zeichen mit iwer selbes hant ### wa ich in svle behvten daz ich daz mvge verstan ### si wanden helt do vristen ez was vf sinen tot getan
###### 911 | ### Si sprach mit kleinen siden næ ich vf sin gewant ### ein tovgenlichez cruce da sol helt din hant ### den minen man behveten soz an die herte gat ### vn– er in starchen sturmen vor sinen vianden stat
###### 912 | ### Daz tvn ich sprach do Hagene vil liebiv frowe min ### do wande ovch des div frowe ez solde ir frvom sin ### da mite was verraten der vil chune man ### vrlovp nam do Hagene do gie er vroliche dan
| ### Daz er revarn hete bat im sin herre sagen ### mvget ir die reise wenden so suln wir riten iagen ### ich han <nv> gar div mære wie ich in gewinnen sol ### mvget ir nv daz gefuege daz tvon ich sprach der kunic wohl
###### 914 | ### Des kuniges ingesinde was allez wol gemvot ### ich wæn immer rechen deheiner mer getvot ### so grozer meinrete so von im ergie ### do sich an sine triwe Chriemh' div kuniginne verlie
###### 915 | ### An dem dritten morgen mit tvsint siner man ### reit der herre Sivrit vroeliche dan ### er wande solde rechen siner friunde leit ### Hagene im reit so nahen daz er geschowet div kleit
###### 916 | ### Als er gesach daz pilde do schicter tovgen dan ### die sagten ander mære zwene siner man ### daz vride habn solde Guntheres lant ### si het der herre Livdeger zvo dem kunige gesant
| ### Wie vngerne Sivrit do hin wider reit ### ern getætes kuniges uinden eteslichiv leit ### wande in vil [35r]chvme erwanden die Guntheres man ### do reit er zv dem kunige der wirt im danchen began
###### 918 | ### Nv lon iv got des willen frivnt Sivrit ### daz ir so willechlichen tvot des ich ivch bite ### daz sol ich immer dienen als ich von rehte sol ### vor allen minen frivnden so getrwoe ich iv wol
###### 919 | ### Nv wir der hereverte ledic worden sin ### so wil ich iagen riten von Wormez vber den Rin ### vn– wil kurcewile zem <Otenwalde> han ### iagen mit den hunden als ich vil dicke han getan
###### 920 | ### Allen minen gesten den sol man daz sagen ### daz ich vil frvo rite die mit mir wellen iagen ### daz si sich bereiten die hie wellen bestan ### hofschen mit den frowen da si mir liebe getan
| ### Do sprach der herre Sivrit in herlichem site ### swenne ir iagen ritet da wil ich gerne mite ### so svlt ir mir <lihen> einen svochman ### vn– eteslichen brachen so rite ich mit iv in den tan
###### 922 | ### Bedurfet ir niht eines sprach der kunic zehant ### ich lihiv welt ir viere den wol ist bechant ### der walt vn– ovch die stige swa div tiere hine gant ### die ivch vrwise nach vns riten niht enlant
###### 923 | ### Do die vil vngetriwen vf geleiten sinen tot ### si wistenz al gemeine Giselher vn– Gernot ### wolden niht iagen riten ine weiz durch welhen nit ### daz si in niht en warenden idoch erarneten siz sit

<<< Übersicht <<< vorige Seite nächste Seite >>>